.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

.. image:: https://coveralls.io/repos/IMIO/plonemeeting.restapi/badge.png?branch=master
   :target: https://coveralls.io/r/IMIO/plonemeeting.restapi?branch=master

.. image:: http://img.shields.io/pypi/v/plonemeeting.restapi.svg
   :alt: PyPI badge
   :target: https://pypi.org/project/plonemeeting.restapi


====================
plonemeeting.restapi
====================

plone.restapi specific endpoints for Products.PloneMeeting


Installation
------------

Install plonemeeting.restapi by adding it to your buildout::

    [buildout]

    ...

    eggs =
        plonemeeting.restapi


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/IMIO/plonemeeting.restapi/issues
- Source Code: https://github.com/IMIO/plonemeeting.restapi


License
-------

The project is licensed under the GPLv2.
